# Make Python Package
Automate new python package creation using boilerplate by [PyPA](https://packaging.python.org/en/latest/tutorials/packaging-projects/)

## The project structure will look like this
```console
NAME/
├── LICENSE
├── pyproject.toml
├── README.md
├── src/
│   └── NAME/
│       └── __init__.py
└── tests/
```

## Installation
```console
pip install mkpypac
```

## Usage
```console
mkpypac NAME
```
